pub enum NumericKind {
Differentiator,
QuadratureFixed,
QuadratureAdaptive,
OdeFixed,
OdeAdaptive,
DaeImplicit,
}Expand description
The category of numeric backend, used to route a plugin to the right slot in the registry.
Variants
Differentiator
A differentiator backend (numeric derivative at a point).
QuadratureFixed
A fixed-rule quadrature backend (definite integral with a set rule).
QuadratureAdaptive
An adaptive quadrature backend (definite integral to a tolerance).
OdeFixed
A fixed-step ODE solver backend.
OdeAdaptive
An adaptive-step ODE solver backend.
DaeImplicit
An implicit differential-algebraic equation solver backend.