pub fn register_differentiator(plugin: Arc<dyn Differentiator>) -> Result<()>
Registers a differentiator backend in the global numeric registry.
Returns an error if the global registry lock is poisoned.