register_differentiator

Function register_differentiator 

pub fn register_differentiator(plugin: Arc<dyn Differentiator>) -> Result<()>
Registers a differentiator backend in the global numeric registry.

Errors

Returns an error if the global registry lock is poisoned.